/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as BasisTheory from "../../../index";
export declare namespace ApplicationKeys {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
    interface IdempotentRequestOptions extends RequestOptions {
        idempotencyKey?: string | undefined;
    }
}
export declare class ApplicationKeys {
    protected readonly _options: ApplicationKeys.Options;
    constructor(_options?: ApplicationKeys.Options);
    /**
     * @param {string} id
     * @param {BasisTheory.ApplicationKeysListRequest} request
     * @param {ApplicationKeys.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applicationKeys.list("id")
     */
    list(id: string, request?: BasisTheory.ApplicationKeysListRequest, requestOptions?: ApplicationKeys.RequestOptions): Promise<BasisTheory.ApplicationKey[]>;
    /**
     * @param {string} id
     * @param {ApplicationKeys.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.UnprocessableEntityError}
     *
     * @example
     *     await client.applicationKeys.create("id")
     */
    create(id: string, requestOptions?: ApplicationKeys.IdempotentRequestOptions): Promise<BasisTheory.ApplicationKey>;
    /**
     * @param {string} id
     * @param {string} keyId
     * @param {ApplicationKeys.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applicationKeys.get("id", "keyId")
     */
    get(id: string, keyId: string, requestOptions?: ApplicationKeys.RequestOptions): Promise<BasisTheory.ApplicationKey>;
    /**
     * @param {string} id
     * @param {string} keyId
     * @param {ApplicationKeys.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applicationKeys.delete("id", "keyId")
     */
    delete(id: string, keyId: string, requestOptions?: ApplicationKeys.RequestOptions): Promise<void>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
