/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as BasisTheory from "../../../index";
export declare namespace Applications {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
    interface IdempotentRequestOptions extends RequestOptions {
        idempotencyKey?: string | undefined;
    }
}
export declare class Applications {
    protected readonly _options: Applications.Options;
    constructor(_options?: Applications.Options);
    /**
     * @param {BasisTheory.ApplicationsListRequest} request
     * @param {Applications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applications.list()
     */
    list(request?: BasisTheory.ApplicationsListRequest, requestOptions?: Applications.RequestOptions): Promise<core.Page<BasisTheory.Application>>;
    /**
     * @param {BasisTheory.CreateApplicationRequest} request
     * @param {Applications.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.applications.create({
     *         name: "name",
     *         type: "type"
     *     })
     */
    create(request: BasisTheory.CreateApplicationRequest, requestOptions?: Applications.IdempotentRequestOptions): Promise<BasisTheory.Application>;
    /**
     * @param {string} id
     * @param {Applications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applications.get("id")
     */
    get(id: string, requestOptions?: Applications.RequestOptions): Promise<BasisTheory.Application>;
    /**
     * @param {string} id
     * @param {BasisTheory.UpdateApplicationRequest} request
     * @param {Applications.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applications.update("id", {
     *         name: "name"
     *     })
     */
    update(id: string, request: BasisTheory.UpdateApplicationRequest, requestOptions?: Applications.IdempotentRequestOptions): Promise<BasisTheory.Application>;
    /**
     * @param {string} id
     * @param {Applications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applications.delete("id")
     */
    delete(id: string, requestOptions?: Applications.RequestOptions): Promise<void>;
    /**
     * @param {Applications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.applications.getByKey()
     */
    getByKey(requestOptions?: Applications.RequestOptions): Promise<BasisTheory.Application>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
