/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as BasisTheory from "../../../index";
export declare namespace Proxies {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
    interface IdempotentRequestOptions extends RequestOptions {
        idempotencyKey?: string | undefined;
    }
}
export declare class Proxies {
    protected readonly _options: Proxies.Options;
    constructor(_options?: Proxies.Options);
    /**
     * @param {BasisTheory.ProxiesListRequest} request
     * @param {Proxies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.proxies.list()
     */
    list(request?: BasisTheory.ProxiesListRequest, requestOptions?: Proxies.RequestOptions): Promise<core.Page<BasisTheory.Proxy>>;
    /**
     * @param {BasisTheory.CreateProxyRequest} request
     * @param {Proxies.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.proxies.create({
     *         name: "name",
     *         destinationUrl: "destination_url"
     *     })
     */
    create(request: BasisTheory.CreateProxyRequest, requestOptions?: Proxies.IdempotentRequestOptions): Promise<BasisTheory.Proxy>;
    /**
     * @param {string} id
     * @param {Proxies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.proxies.get("id")
     */
    get(id: string, requestOptions?: Proxies.RequestOptions): Promise<BasisTheory.Proxy>;
    /**
     * @param {string} id
     * @param {BasisTheory.UpdateProxyRequest} request
     * @param {Proxies.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.proxies.update("id", {
     *         name: "name",
     *         destinationUrl: "destination_url"
     *     })
     */
    update(id: string, request: BasisTheory.UpdateProxyRequest, requestOptions?: Proxies.IdempotentRequestOptions): Promise<BasisTheory.Proxy>;
    /**
     * @param {string} id
     * @param {Proxies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.proxies.delete("id")
     */
    delete(id: string, requestOptions?: Proxies.RequestOptions): Promise<void>;
    /**
     * @param {string} id
     * @param {BasisTheory.PatchProxyRequest} request
     * @param {Proxies.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.proxies.patch("id")
     */
    patch(id: string, request?: BasisTheory.PatchProxyRequest, requestOptions?: Proxies.IdempotentRequestOptions): Promise<void>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
