/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as BasisTheory from "../../../index";
import { Results } from "../resources/results/client/Client";
export declare namespace Reactors {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
    interface IdempotentRequestOptions extends RequestOptions {
        idempotencyKey?: string | undefined;
    }
}
export declare class Reactors {
    protected readonly _options: Reactors.Options;
    protected _results: Results | undefined;
    constructor(_options?: Reactors.Options);
    get results(): Results;
    /**
     * @param {BasisTheory.ReactorsListRequest} request
     * @param {Reactors.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.reactors.list()
     */
    list(request?: BasisTheory.ReactorsListRequest, requestOptions?: Reactors.RequestOptions): Promise<core.Page<BasisTheory.Reactor>>;
    /**
     * @param {BasisTheory.CreateReactorRequest} request
     * @param {Reactors.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.reactors.create({
     *         name: "name",
     *         code: "code"
     *     })
     */
    create(request: BasisTheory.CreateReactorRequest, requestOptions?: Reactors.IdempotentRequestOptions): Promise<BasisTheory.Reactor>;
    /**
     * @param {string} id
     * @param {Reactors.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.reactors.get("id")
     */
    get(id: string, requestOptions?: Reactors.RequestOptions): Promise<BasisTheory.Reactor>;
    /**
     * @param {string} id
     * @param {BasisTheory.UpdateReactorRequest} request
     * @param {Reactors.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.reactors.update("id", {
     *         name: "name",
     *         code: "code"
     *     })
     */
    update(id: string, request: BasisTheory.UpdateReactorRequest, requestOptions?: Reactors.IdempotentRequestOptions): Promise<BasisTheory.Reactor>;
    /**
     * @param {string} id
     * @param {Reactors.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.reactors.delete("id")
     */
    delete(id: string, requestOptions?: Reactors.RequestOptions): Promise<void>;
    /**
     * @param {string} id
     * @param {BasisTheory.PatchReactorRequest} request
     * @param {Reactors.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.reactors.patch("id")
     */
    patch(id: string, request?: BasisTheory.PatchReactorRequest, requestOptions?: Reactors.IdempotentRequestOptions): Promise<void>;
    /**
     * @param {string} id
     * @param {BasisTheory.ReactRequest} request
     * @param {Reactors.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     * @throws {@link BasisTheory.UnprocessableEntityError}
     *
     * @example
     *     await client.reactors.react("id")
     */
    react(id: string, request?: BasisTheory.ReactRequest, requestOptions?: Reactors.RequestOptions): Promise<BasisTheory.ReactResponse>;
    /**
     * @param {string} id
     * @param {BasisTheory.ReactRequestAsync} request
     * @param {Reactors.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     * @throws {@link BasisTheory.UnprocessableEntityError}
     *
     * @example
     *     await client.reactors.reactAsync("id")
     */
    reactAsync(id: string, request?: BasisTheory.ReactRequestAsync, requestOptions?: Reactors.RequestOptions): Promise<BasisTheory.AsyncReactResponse>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
