/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../../../environments";
import * as core from "../../../../../../core";
import * as BasisTheory from "../../../../../index";
export declare namespace Sessions {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
    interface IdempotentRequestOptions extends RequestOptions {
        idempotencyKey?: string | undefined;
    }
}
export declare class Sessions {
    protected readonly _options: Sessions.Options;
    constructor(_options?: Sessions.Options);
    /**
     * @param {BasisTheory.threeds.CreateThreeDsSessionRequest} request
     * @param {Sessions.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.threeds.sessions.create()
     */
    create(request?: BasisTheory.threeds.CreateThreeDsSessionRequest, requestOptions?: Sessions.RequestOptions): Promise<BasisTheory.CreateThreeDsSessionResponse>;
    /**
     * @param {string} sessionId
     * @param {BasisTheory.threeds.AuthenticateThreeDsSessionRequest} request
     * @param {Sessions.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.threeds.sessions.authenticate("sessionId", {
     *         authenticationCategory: "authentication_category",
     *         authenticationType: "authentication_type"
     *     })
     */
    authenticate(sessionId: string, request: BasisTheory.threeds.AuthenticateThreeDsSessionRequest, requestOptions?: Sessions.IdempotentRequestOptions): Promise<BasisTheory.ThreeDsAuthentication>;
    /**
     * @param {string} sessionId
     * @param {Sessions.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.threeds.sessions.getChallengeResult("sessionId")
     */
    getChallengeResult(sessionId: string, requestOptions?: Sessions.RequestOptions): Promise<BasisTheory.ThreeDsAuthentication>;
    /**
     * @param {string} id
     * @param {Sessions.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.threeds.sessions.get("id")
     */
    get(id: string, requestOptions?: Sessions.RequestOptions): Promise<BasisTheory.ThreeDsSession>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
