/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as BasisTheory from "../../../index";
export declare namespace Tokens {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
    interface IdempotentRequestOptions extends RequestOptions {
        idempotencyKey?: string | undefined;
    }
}
export declare class Tokens {
    protected readonly _options: Tokens.Options;
    constructor(_options?: Tokens.Options);
    /**
     * @param {unknown} request
     * @param {Tokens.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.ConflictError}
     *
     * @example
     *     await client.tokens.detokenize({
     *         "key": "value"
     *     })
     */
    detokenize(request?: unknown, requestOptions?: Tokens.RequestOptions): Promise<unknown>;
    /**
     * @param {unknown} request
     * @param {Tokens.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.ConflictError}
     *
     * @example
     *     await client.tokens.tokenize({
     *         "key": "value"
     *     })
     */
    tokenize(request?: unknown, requestOptions?: Tokens.IdempotentRequestOptions): Promise<unknown>;
    /**
     * @param {BasisTheory.TokensListRequest} request
     * @param {Tokens.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.tokens.list()
     */
    list(request?: BasisTheory.TokensListRequest, requestOptions?: Tokens.RequestOptions): Promise<core.Page<BasisTheory.Token>>;
    /**
     * @param {BasisTheory.CreateTokenRequest} request
     * @param {Tokens.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.ConflictError}
     *
     * @example
     *     await client.tokens.create()
     */
    create(request?: BasisTheory.CreateTokenRequest, requestOptions?: Tokens.IdempotentRequestOptions): Promise<BasisTheory.Token>;
    /**
     * @param {BasisTheory.SearchTokensRequest} request
     * @param {Tokens.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.tokens.search()
     */
    search(request?: BasisTheory.SearchTokensRequest, requestOptions?: Tokens.IdempotentRequestOptions): Promise<core.Page<BasisTheory.Token>>;
    /**
     * @param {string} id
     * @param {Tokens.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.tokens.get("id")
     */
    get(id: string, requestOptions?: Tokens.RequestOptions): Promise<BasisTheory.Token>;
    /**
     * @param {string} id
     * @param {Tokens.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.tokens.delete("id")
     */
    delete(id: string, requestOptions?: Tokens.RequestOptions): Promise<void>;
    /**
     * @param {string} id
     * @param {BasisTheory.UpdateTokenRequest} request
     * @param {Tokens.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     * @throws {@link BasisTheory.ConflictError}
     *
     * @example
     *     await client.tokens.update("id")
     */
    update(id: string, request?: BasisTheory.UpdateTokenRequest, requestOptions?: Tokens.IdempotentRequestOptions): Promise<BasisTheory.Token>;
    /**
     * @param {BasisTheory.TokensListV2Request} request
     * @param {Tokens.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.tokens.listV2()
     */
    listV2(request?: BasisTheory.TokensListV2Request, requestOptions?: Tokens.RequestOptions): Promise<core.Page<BasisTheory.Token>>;
    /**
     * @param {BasisTheory.SearchTokensRequestV2} request
     * @param {Tokens.IdempotentRequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.tokens.searchV2()
     */
    searchV2(request?: BasisTheory.SearchTokensRequestV2, requestOptions?: Tokens.IdempotentRequestOptions): Promise<core.Page<BasisTheory.Token>>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
