/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as BasisTheory from "../../../index";
import { Events } from "../resources/events/client/Client";
export declare namespace Webhooks {
    interface Options {
        environment?: core.Supplier<environments.BasisTheoryEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string | undefined>;
        /** Override the BT-TRACE-ID header */
        correlationId?: core.Supplier<string | undefined>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the BT-TRACE-ID header */
        correlationId?: string | undefined;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Webhooks {
    protected readonly _options: Webhooks.Options;
    protected _events: Events | undefined;
    constructor(_options?: Webhooks.Options);
    get events(): Events;
    /**
     * Simple endpoint that can be utilized to verify the application is running
     *
     * @param {Webhooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.webhooks.ping()
     */
    ping(requestOptions?: Webhooks.RequestOptions): Promise<void>;
    /**
     * Returns the webhook
     *
     * @param {string} id
     * @param {Webhooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.webhooks.get("id")
     */
    get(id: string, requestOptions?: Webhooks.RequestOptions): Promise<BasisTheory.Webhook>;
    /**
     * Update a new webhook
     *
     * @param {string} id
     * @param {BasisTheory.UpdateWebhookRequest} request
     * @param {Webhooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.webhooks.update("id", {
     *         name: "webhook-update",
     *         url: "http://www.example.com",
     *         events: ["token:created"]
     *     })
     */
    update(id: string, request: BasisTheory.UpdateWebhookRequest, requestOptions?: Webhooks.RequestOptions): Promise<BasisTheory.Webhook>;
    /**
     * Delete a new webhook
     *
     * @param {string} id
     * @param {Webhooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.NotFoundError}
     *
     * @example
     *     await client.webhooks.delete("id")
     */
    delete(id: string, requestOptions?: Webhooks.RequestOptions): Promise<void>;
    /**
     * Returns the configured webhooks
     *
     * @param {Webhooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     *
     * @example
     *     await client.webhooks.list()
     */
    list(requestOptions?: Webhooks.RequestOptions): Promise<BasisTheory.WebhookList>;
    /**
     * Create a new webhook
     *
     * @param {BasisTheory.CreateWebhookRequest} request
     * @param {Webhooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link BasisTheory.BadRequestError}
     * @throws {@link BasisTheory.UnauthorizedError}
     * @throws {@link BasisTheory.ForbiddenError}
     * @throws {@link BasisTheory.UnprocessableEntityError}
     *
     * @example
     *     await client.webhooks.create({
     *         name: "webhook-create",
     *         url: "http://www.example.com",
     *         events: ["token:created"]
     *     })
     */
    create(request: BasisTheory.CreateWebhookRequest, requestOptions?: Webhooks.RequestOptions): Promise<BasisTheory.Webhook>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "BT-API-KEY": string | undefined;
    }>;
}
